/* Chromosome.hpp
   interface for the class chromosome. It is implemented as a pointer to an array 
   of double-type genes and a fitness.
   @author	Hyun Kim
   @date	11/20/99
*/

#ifndef _CHROMOSOME_HPP
#define _CHROMOSOME_HPP

#include <iostream.h>
#include <fstream.h>

class Chromosome
{
	friend ostream& operator<<( ostream& out, Chromosome& chrom );
	friend ofstream& operator<<( ofstream& out, Chromosome& chrom );

private:
	double*	genes;
	double	fitness;
	int		length;		// length of the chromosome

public:
	Chromosome();
	Chromosome( Chromosome& chrom );
	~Chromosome();
	double&		operator[]( int i );	// return the point of the i-th gene's value
	Chromosome&	operator=( Chromosome& chrom );
	void	setLength( int n ) { length = n; };
	int		getLength() const { return length; };
	void	setFitness( double f ) { fitness = f; };
	double	getFitness() const { return fitness; };
	double&	getGenes( int i ) const { return genes[ i ]; };
	void	random();
	void	evaluate();
	int		getRandomPoint();
	void	transpose();
	void	mutate();
	void	adjust( int n );			// n is the # of genes adjusted
	double	objectiveFunction();
};

#endif 

