/* Parameter.hpp
   interface for the class parameter. It is not really a "class". it's just a 
   collection of all necessary parameters for portfolio problems.
   @author	Hyun Kim
   @date	11/20/99
*/

#ifndef _PARAMETER_HPP
#define _PARAMETER_HPP

#include <fstream.h>
#include "Population.hpp"

#define MAXGENES 100		// max. size of genes

enum SelectionType { roulette_wheel_selection, tournament_with_replacement };
enum CrossoverType { ptx_1, ptx_2, uniform, linx, alinx_1, alinx_2, alinx_3, alinx_4 };

void			report( ofstream& f, int gen, Population* pop );
void			analyze( ofstream& f, int gen, Population* pop );
void			result( ofstream& f, Population* pop );
void			readParameters( ifstream& in );
void			printParameters( ofstream& out );
void			readExpReturn( ifstream& in );
void			readStdDevReturn( ifstream& in );
void			readCorrelation( ifstream& in );
SelectionType	findSelectionOp( char* s );
CrossoverType	findCrossoverOp( char* s );

class Parameter
{
public:
	Parameter();
	~Parameter();

	static int				popsize;				// population size, i.e. number of chromosomes
	static int				genes;					// number of genes, i.e. length of the chromosome, here number of assets
	static double			riskfree;				// risk free rate
	static double*			expReturn;				// expected return of each asset
	static double*			stdDevReturn;			// standard deviation of return
	static double*			correlation[MAXGENES];	// correlation between a pair of assets
	static SelectionType	selection;				// selection methods used
	static CrossoverType	crossover;				// crossover operator used
	static double			mutationRate;			// fixed as 1/(# of genes)
	static double			seed;					// seed for random number generator.
	//static CriteriaType		stop_criteria;			// stop criteria.
};

#endif
